@@ -66,22 +66,22 @@
 (define (get-base-string)
   (cond ((and (> BASE-VAL 1)
 	      (< BASE-VAL 11))
-	 (string-append (_"Base Card:  ") (number->string BASE-VAL)))
+	 (string-append (_"Base Card: ") (number->string BASE-VAL)))
 	((= BASE-VAL 1)
-	 (_"Base Card:  Ace"))
+	 (_"Base Card: Ace"))
 	((= BASE-VAL 11)
-	 (_"Base Card:  Jack"))
+	 (_"Base Card: Jack"))
 	((= BASE-VAL 12)
-	 (_"Base Card:  Queen"))
+	 (_"Base Card: Queen"))
 	((= BASE-VAL 13)
-	 (_"Base Card:  King"))
+	 (_"Base Card: King"))
 	(#t #f)))
 
 (define (get-stock-no-string)
   (if (> (length (get-cards 0)) 1)
-      (string-append (_"Stock left:  ")
+      (string-append (_"Stock left:") " "
 		     (number->string (length (get-cards 0))))
-      (string-append (_"Stock left:  0")))) 
+      (string-append (_"Stock left: 0")))) 
 
 (define (check-straight-descending-list card-list)
   (or (< (length card-list) 2)
